# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GetV20DnsLiveResponseDnsRecordsItem(UniversalBaseModel):
    name: typing.Optional[str] = None
    type: typing.Optional[int] = None
    dns_type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="dnsType")] = None
    ttl: typing.Optional[int] = None
    raw_text: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="rawText")] = None
    rrset_type: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="rrsetType")] = None
    single_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="singleName")] = None
    address: typing.Optional[str] = None
    target: typing.Optional[str] = None
    priority: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
