# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetV10WhoisResponseRegistryData(UniversalBaseModel):
    domain_name: typing.Optional[str] = None
    query_time: typing.Optional[dt.datetime] = None
    whois_server: typing.Optional[str] = None
    domain_registered: typing.Optional[str] = None
    create_date: typing.Optional[str] = None
    update_date: typing.Optional[str] = None
    expiry_date: typing.Optional[str] = None
    domain_registrar: typing.Optional[typing.Dict[str, str]] = None
    name_servers: typing.Optional[typing.List[str]] = None
    domain_status: typing.Optional[typing.List[str]] = None
    whois_raw_registry: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
