# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .get_v_20_dns_live_response_dns_records_item import GetV20DnsLiveResponseDnsRecordsItem


class GetV20DnsLiveResponse(UniversalBaseModel):
    query_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="queryTime")] = None
    domain_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="domainName")] = None
    dns_types: typing_extensions.Annotated[typing.Optional[typing.Dict[str, int]], FieldMetadata(alias="dnsTypes")] = (
        None
    )
    dns_records: typing_extensions.Annotated[
        typing.Optional[typing.List[GetV20DnsLiveResponseDnsRecordsItem]], FieldMetadata(alias="dnsRecords")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
