# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_v_21_dns_reverse_response_reverse_dns_records_item import GetV21DnsReverseResponseReverseDnsRecordsItem


class GetV21DnsReverseResponse(UniversalBaseModel):
    total_records: typing.Optional[int] = None
    total_pages: typing.Optional[int] = None
    current_page: typing.Optional[int] = None
    reverse_dns_records: typing.Optional[typing.List[GetV21DnsReverseResponseReverseDnsRecordsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
