# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_v_10_domain_availability_response_domain_available_response_item import (
    GetV10DomainAvailabilityResponseDomainAvailableResponseItem,
)


class GetV10DomainAvailabilityResponse(UniversalBaseModel):
    domain_available_response: typing.Optional[
        typing.List[GetV10DomainAvailabilityResponseDomainAvailableResponseItem]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
