# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GetV10AsnWhoisResponseAutNumsItem(UniversalBaseModel):
    aut_num: typing.Optional[str] = None
    as_name: typing.Optional[str] = None
    description: typing.Optional[typing.List[str]] = None
    status: typing.Optional[str] = None
    import_: typing_extensions.Annotated[typing.Optional[typing.List[str]], FieldMetadata(alias="import")] = None
    export: typing.Optional[typing.List[str]] = None
    organization: typing.Optional[str] = None
    sponsoring_organization: typing.Optional[str] = None
    admin_contacts: typing.Optional[typing.List[str]] = None
    tech_contacts: typing.Optional[typing.List[str]] = None
    mnt_by: typing.Optional[typing.List[str]] = None
    date_created: typing.Optional[str] = None
    date_updated: typing.Optional[str] = None
    source: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
