# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetV10IpWhoisResponseInetNumsItem(UniversalBaseModel):
    start_ip: typing.Optional[str] = None
    end_ip: typing.Optional[str] = None
    cidr: typing.Optional[typing.List[str]] = None
    net_name: typing.Optional[str] = None
    net_handle: typing.Optional[str] = None
    status: typing.Optional[str] = None
    organization: typing.Optional[str] = None
    date_created: typing.Optional[str] = None
    date_updated: typing.Optional[str] = None
    source: typing.Optional[str] = None
    parents: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
